#!/bin/bash

if [ "$#" -ne 1 ]; then
    echo "You must supply float or double as a command line parameter"
    echo "   to indicate the FFTW precision for the FIR engine."
    echo "The level of precision should be supported by FFTW (see"
    echo "   configuring FFTW in the FFTW installation docs."
    echo "Please try again."
    exit 2
fi

if [ "$1" = "float" ] || [ "$1" = "single" ]; then
  echo "compiling the FIR engine in single precision..."
  g++ --std=c++11 -march=native -O2 -ffast-math -DFFT_DATATYPE=1 ./FIR_convolution_engine.cpp -lfftw3f -lm -o FIR_engine.exe
else
  echo "compiling the FIR engine in double precision..."
  g++ --std=c++11 -march=native -O2 -ffast-math -DFFT_DATATYPE=2 ./FIR_convolution_engine.cpp -lfftw3 -lm -o FIR_engine.exe
fi
if [ $? = 0 ]; then
  echo "The FIR engine was successfully compiled into the executable file FIR_engine.exe"
else
  echo "An error was encountered. Please try again."
fi
echo
